@@ -1,6 +1,6 @@
 package Chemistry::Mol;
-$VERSION = '0.21';
-# $Id: Mol.pm,v 1.26 2004/05/13 14:59:09 itubert Exp $
+$VERSION = '0.22';
+# $Id: Mol.pm,v 1.27 2004/05/18 01:26:59 itubert Exp $
 
 =head1 NAME
 
@@ -112,6 +112,14 @@ sub add_atom {
     $_[-1];
 }
 
+sub add_atom_np {
+    my $self = shift;
+    for my $atom (@_){
+        push @{$self->{atoms}}, $atom;
+        $self->{byId}{$atom->id} = $atom;
+    }
+    $_[-1];
+}
 =item $mol->new_atom(name => value, ...)
 
 Shorthand for $mol->add_atom(Chemistry::Atom->new(name => value, ...));
@@ -174,6 +182,15 @@ sub add_bond {
     $_[-1];
 }
 
+sub add_bond_np {
+    my $self = shift;
+    for my $bond (@_){
+        push @{$self->{bonds}}, $bond;
+	$self->{byId}{$bond->id} = $bond;
+    }
+    $_[-1];
+}
+
 =item $mol->new_bond(name => value, ...)
 
 Shorthand for $mol->add_bond(Chemistry::Bond->new(name => value, ...));
@@ -630,7 +647,7 @@ sub _paint {
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 SEE ALSO
 
